pub struct CloudPlan {
pub id: String,
pub name: String,
pub paddle_price_id: String,
pub memory_mb_default: i32,
pub volume_gb: i32,
pub max_tenants: Option<i32>,
}Available on crate feature
core only.Fields
id: Stringname: Stringpaddle_price_id: Stringmemory_mb_default: i32volume_gb: i32max_tenants: Option<i32>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for CloudPlan
impl<'de> Deserialize<'de> for CloudPlan
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CloudPlan, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CloudPlan, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CloudPlan
impl JsonSchema for CloudPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for CloudPlan
impl Serialize for CloudPlan
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more