pub struct CloudTenant {
pub id: String,
pub name: String,
pub fly_app_name: Option<String>,
pub fly_hostname: Option<String>,
pub hostname: Option<String>,
}Available on crate feature
core only.Fields
id: Stringname: Stringfly_app_name: Option<String>fly_hostname: Option<String>hostname: Option<String>Trait Implementations
Sourceimpl Clone for CloudTenant
impl Clone for CloudTenant
Sourcefn clone(&self) -> CloudTenant
fn clone(&self) -> CloudTenant
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CloudTenant
impl Debug for CloudTenant
Sourceimpl<'de> Deserialize<'de> for CloudTenant
impl<'de> Deserialize<'de> for CloudTenant
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CloudTenant, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CloudTenant, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CloudTenant
impl JsonSchema for CloudTenant
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for CloudTenant
impl Serialize for CloudTenant
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more