pub struct SectionLayout {
pub width: LayoutWidth,
pub order: u32,
}Available on crate feature
core only.Fields
width: LayoutWidthorder: u32Trait Implementations
Sourceimpl Clone for SectionLayout
impl Clone for SectionLayout
Sourcefn clone(&self) -> SectionLayout
fn clone(&self) -> SectionLayout
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SectionLayout
impl Debug for SectionLayout
Sourceimpl Default for SectionLayout
impl Default for SectionLayout
Sourcefn default() -> SectionLayout
fn default() -> SectionLayout
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SectionLayout
impl<'de> Deserialize<'de> for SectionLayout
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SectionLayout, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SectionLayout, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SectionLayout
impl JsonSchema for SectionLayout
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for SectionLayout
impl Serialize for SectionLayout
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for SectionLayout