pub struct RenderingHints {
pub columns: Option<Vec<String>>,
pub chart_type: Option<String>,
pub theme: Option<String>,
pub extra: HashMap<String, Value>,
}Available on crate feature
core only.Fields
columns: Option<Vec<String>>chart_type: Option<String>theme: Option<String>extra: HashMap<String, Value>Trait Implementations
Sourceimpl Clone for RenderingHints
impl Clone for RenderingHints
Sourcefn clone(&self) -> RenderingHints
fn clone(&self) -> RenderingHints
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RenderingHints
impl Debug for RenderingHints
Sourceimpl Default for RenderingHints
impl Default for RenderingHints
Sourcefn default() -> RenderingHints
fn default() -> RenderingHints
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RenderingHints
impl<'de> Deserialize<'de> for RenderingHints
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<RenderingHints, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<RenderingHints, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RenderingHints
impl JsonSchema for RenderingHints
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for RenderingHints
impl Serialize for RenderingHints
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more